==> noahs-2.0.7.tar.gz: noahs/src/Plugin/Control/ControlNoahsGallery.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;
use Drupal\noahs_page_builder\Fonts;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;

/**
 * @ControlPlugin(
 *   id = "noahs_gallery",
 *   label = @Translation("Gallery")
 * )
 */
class ControlNoahsGallery extends ControlBase{
	
	public function get_type() {
		return 'noahs_gallery';
	}

	public function content_template($content, $element, $delta, $first) {
		$items = $value ? $value : [];
		$data_field = [];
	
		$html = '';
	
		$html .= '<div class="noahs_page_builder_gallery_field">';
		$html .= '<div id="' . $data['item_id'] . '">';
		$html .= '<div class="gallery-images-wrapper p-3 mb-3 bg-light rounded-3 row position-relative" id="gallery-images-wrapper">';
	
		foreach ($items as $i => $item) {
			$image = '';
	
			if (isset($item['fid'])) {
				$file = File::load($item['fid']);
				$file_uri = $file->getFileUri();
				$image = ImageStyle::load('thumbnail')->buildUrl($file_uri);
			}
	
			$html .= '<div class="col-3 image-box mb-2 position-relative" data-delta="' . $i . '">';
			$html .= '<div class="noahs_gallery_field_actions">';
			$html .= '<div class="noahs_page_builder-edit-grid-item btn btn-sm btn-info position-absolute top-50 start-50 translate-middle rounded-circle" data-show-click="#edit-gallery-image-' . $i . '"><i class="fa-solid fa-pen-to-square"></i></div>';
			$html .= '<div class="noahs_page_builder-move-grid-item btn btn-sm btn-info position-absolute top-0 start-0 rounded-circle"><i class="fa-solid fa-arrows-up-down-left-right"></i></div>';
			$html .= '<div class="noahs_page_builder-remove-grid-item btn btn-sm btn-danger position-absolute bottom-0 end-0 rounded-circle"><i class="fa-solid fa-trash"></i></div>';
			$html .= '</div>';
			$html .= '<img src="' . $image . '" style="width:100%; height:auto;">';
			$html .= '<div id="edit-gallery-image-' . $i . '" class="noahs_page_builder-hover-modal bg-light p-3 position-absolute top-100 start-50 translate-middle-x shadow-lg hidden">';
			$html .= '<div class="btn btn-sm btn-danger position-absolute top-0 start-50 translate-middle rounded-circle" data-show-click="#edit-gallery-image-' . $i . '"><i class="fa-regular fa-circle-xmark"></i></div>';
			$html .= '<input class="form-control mb-3" type="hidden" name="element[gallery_items][' . $i . '][fid]" value="' . ($item['fid'] ?? '') . '">';
			$html .= '<input class="form-control select2-control url_autocomplete ui-autocomplete-input" type="text" name="element[gallery_items][' . $i . '][url]" value="' . ($item['url'] ?? '') . '">';
			$html .= '<input type="hidden" name="element[gallery_items][' . $i . '][node_id]" value="' . (!empty($value['node_id']) ? $value['node_id'] : '') . '" class="node_id" field-settings/>';
			$html .= '</div>';
			$html .= '</div>';
		}
	
		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';
	
		return $html;
	}
	
	protected function get_default_settings() {
		return [
			'input_type' => 'noahs_gallery',
			'placeholder' => '',
			'title' => '',
		];
	}
}

==> noahs-2.1.3.tar.gz: noahs/src/Plugin/Control/ControlNoahsGallery.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;
use Drupal\file\Entity\File;
use Drupal\image\Entity\ImageStyle;
use Drupal\media\Entity\Media;

/**
 * @ControlPlugin(
 *   id = "noahs_gallery",
 *   label = @Translation("Gallery")
 * )
 */
class ControlNoahsGallery extends ControlBase{
	
	public function get_type() {
		return 'noahs_gallery';
	}

	public function content_template(array $params = []) {
		$data = $params['data'] ?? null;
		$name = $params['name'] ?? null;
		$value = $params['value'] ?? null;

		$items = $value ? $value : [];
		$data_field = [];
	
		$html = '';
	
		$html .= '<div class="noahs_page_builder_gallery_field">';
		$html .= '<div id="' . $data['item_id'] . '">';
		$html .= '<div class="gallery-images-wrapper p-3 mb-3 bg-light rounded-3 row position-relative" id="gallery-images-wrapper">';

		foreach ($items as $i => $item) {
			$image = '';
			if (isset($item['fid'])) {
				$media = Media::load($item['fid']);
            	if ($media && $media->bundle() === 'image') {
               		$media_field_name = 'field_media_image'; 
               		if ($media->hasField($media_field_name) && !$media->get($media_field_name)->isEmpty()) {
						$file = $media->get($media_field_name)->entity;
						if(!empty($file)){
							$file_uri = $file->getFileUri();
							$image = ImageStyle::load('thumbnail')->buildUrl($file_uri);
						}
					}
               }
			}
	
			$html .= '<div class="col-3 image-box mb-2 position-relative" data-caca="'.$item['fid'].'" data-delta="' . $i . '">';
			$html .= '<div class="noahs_gallery_field_actions">';
			$html .= '<div class="noahs_page_builder-edit-grid-item btn btn-sm btn-info position-absolute top-50 start-50 translate-middle rounded-circle" data-show-click="#edit-gallery-image-' . $i . '"><i class="fa-solid fa-pen-to-square"></i></div>';
			$html .= '<div class="noahs_page_builder-move-grid-item btn btn-sm btn-info position-absolute top-0 start-0 rounded-circle"><i class="fa-solid fa-arrows-up-down-left-right"></i></div>';
			$html .= '<button class="noahs_page_builder-remove-grid-item btn btn-sm btn-danger position-absolute bottom-0 end-0 rounded-circle"><i class="fa-solid fa-trash"></i></button>';
			$html .= '</div>';
			$html .= '<img src="' . $image . '" style="width:100%; height:auto;">';
			$html .= '<div id="edit-gallery-image-' . $i . '" class="noahs_page_builder-hover-modal bg-light p-3 position-absolute top-100 start-50 translate-middle-x shadow-lg hidden">';
			$html .= '<div class="btn btn-sm btn-danger position-absolute top-0 start-50 translate-middle rounded-circle" data-show-click="#edit-gallery-image-' . $i . '"><i class="fa-regular fa-circle-xmark"></i></div>';
			$html .= '<input class="form-control mb-3" type="hidden" name="element[gallery_items][' . $i . '][fid]" value="' . ($item['fid'] ?? '') . '">';
			$html .= '<input class="form-control select2-control url_autocomplete ui-autocomplete-input" type="text" name="element[gallery_items][' . $i . '][url]" value="' . ($item['url'] ?? '') . '">';
			$html .= '<input type="hidden" name="element[gallery_items][' . $i . '][node_id]" value="' . (!empty($value['node_id']) ? $value['node_id'] : '') . '" class="node_id" field-settings/>';
			$html .= '</div>';
			$html .= '</div>';
		}
	
		$html .= '</div>';
		$html .= '</div>';
		$html .= '</div>';
	
		return $html;
	}
	
	public function get_default_settings() {
		return [
			'input_type' => 'noahs_gallery',
			'placeholder' => '',
			'title' => '',
		];
	}
}
